pub struct EncryptedProxy<'p>(/* private fields */);Implementations
Sourceimpl<'p> EncryptedProxy<'p>
impl<'p> EncryptedProxy<'p>
Sourcepub async fn new(conn: &Connection) -> Result<EncryptedProxy<'p>>
pub async fn new(conn: &Connection) -> Result<EncryptedProxy<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub async fn change_passphrase(
&self,
passphrase: &str,
new_passphrase: &str,
options: HashMap<&str, Value<'_>>,
) -> Result<()>
pub async fn change_passphrase( &self, passphrase: &str, new_passphrase: &str, options: HashMap<&str, Value<'_>>, ) -> Result<()>
ChangePassphrase method
Sourcepub async fn resize(
&self,
size: u64,
options: HashMap<&str, Value<'_>>,
) -> Result<()>
pub async fn resize( &self, size: u64, options: HashMap<&str, Value<'_>>, ) -> Result<()>
Resize method
Sourcepub async fn unlock(
&self,
passphrase: &str,
options: HashMap<&str, Value<'_>>,
) -> Result<OwnedObjectPath>
pub async fn unlock( &self, passphrase: &str, options: HashMap<&str, Value<'_>>, ) -> Result<OwnedObjectPath>
Unlock method
Sourcepub async fn child_configuration(
&self,
) -> Result<Vec<(String, HashMap<String, OwnedValue>)>>
pub async fn child_configuration( &self, ) -> Result<Vec<(String, HashMap<String, OwnedValue>)>>
ChildConfiguration property
Sourcepub fn cached_child_configuration(
&self,
) -> Result<Option<<Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>
pub fn cached_child_configuration( &self, ) -> Result<Option<<Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>
ChildConfiguration property
Get the cached value of the ChildConfiguration property, or None if the property is not cached.
Sourcepub async fn receive_child_configuration_changed(
&self,
) -> PropertyStream<'p, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>
pub async fn receive_child_configuration_changed( &self, ) -> PropertyStream<'p, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>
ChildConfiguration property
Create a stream for the ChildConfiguration property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn cleartext_device(&self) -> Result<OwnedObjectPath>
pub async fn cleartext_device(&self) -> Result<OwnedObjectPath>
CleartextDevice property
Sourcepub fn cached_cleartext_device(
&self,
) -> Result<Option<<Result<OwnedObjectPath> as ResultAdapter>::Ok>, <Result<OwnedObjectPath> as ResultAdapter>::Err>
pub fn cached_cleartext_device( &self, ) -> Result<Option<<Result<OwnedObjectPath> as ResultAdapter>::Ok>, <Result<OwnedObjectPath> as ResultAdapter>::Err>
CleartextDevice property
Get the cached value of the CleartextDevice property, or None if the property is not cached.
Sourcepub async fn receive_cleartext_device_changed(
&self,
) -> PropertyStream<'p, <Result<OwnedObjectPath> as ResultAdapter>::Ok>
pub async fn receive_cleartext_device_changed( &self, ) -> PropertyStream<'p, <Result<OwnedObjectPath> as ResultAdapter>::Ok>
CleartextDevice property
Create a stream for the CleartextDevice property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn hint_encryption_type(&self) -> Result<String>
pub async fn hint_encryption_type(&self) -> Result<String>
HintEncryptionType property
Sourcepub fn cached_hint_encryption_type(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_hint_encryption_type( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
HintEncryptionType property
Get the cached value of the HintEncryptionType property, or None if the property is not cached.
Sourcepub async fn receive_hint_encryption_type_changed(
&self,
) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
pub async fn receive_hint_encryption_type_changed( &self, ) -> PropertyStream<'p, <Result<String> as ResultAdapter>::Ok>
HintEncryptionType property
Create a stream for the HintEncryptionType property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.
Sourcepub async fn metadata_size(&self) -> Result<u64>
pub async fn metadata_size(&self) -> Result<u64>
MetadataSize property
Sourcepub fn cached_metadata_size(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_metadata_size( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
MetadataSize property
Get the cached value of the MetadataSize property, or None if the property is not cached.
Sourcepub async fn receive_metadata_size_changed(
&self,
) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>
pub async fn receive_metadata_size_changed( &self, ) -> PropertyStream<'p, <Result<u64> as ResultAdapter>::Ok>
MetadataSize property
Create a stream for the MetadataSize property changes. This is a convenient wrapper around zbus::Proxy::receive_property_changed.