MDRaidProxyBlocking

Struct MDRaidProxyBlocking 

pub struct MDRaidProxyBlocking<'p>(/* private fields */);

Implementations

Source

impl<'p> MDRaidProxyBlocking<'p>

pub fn new(conn: &Connection) -> Result<MDRaidProxyBlocking<'p>>

Creates a new proxy with the default service and path.

pub fn builder(conn: &Connection) -> Builder<'p, Self>

Returns a customizable builder for this proxy.

pub fn into_inner(self) -> Proxy<'p>

Consumes self, returning the underlying zbus::Proxy.

pub fn inner(&self) -> &Proxy<'p>

The reference to the underlying zbus::Proxy.

pub fn inner_mut(&mut self) -> &mut Proxy<'p>

The mutable reference to the underlying zbus::Proxy.

pub fn add_device( &self, device: &ObjectPath<'_>, options: HashMap<&str, Value<'_>>, ) -> Result<()>

AddDevice method

pub fn delete(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

Delete method

pub fn remove_device( &self, device: &ObjectPath<'_>, options: HashMap<&str, Value<'_>>, ) -> Result<()>

RemoveDevice method

pub fn request_sync_action( &self, sync_action: &str, options: HashMap<&str, Value<'_>>, ) -> Result<()>

RequestSyncAction method

pub fn set_bitmap_location( &self, value: &[u8], options: HashMap<&str, Value<'_>>, ) -> Result<()>

SetBitmapLocation method

pub fn start(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

Start method

pub fn stop(&self, options: HashMap<&str, Value<'_>>) -> Result<()>

Stop method

pub fn active_devices( &self, ) -> Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>>

ActiveDevices property

pub fn cached_active_devices( &self, ) -> Result<Option<<Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>

ActiveDevices property Get the cached value of the ActiveDevices property, or None if the property is not cached.

pub fn receive_active_devices_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>

ActiveDevices property Create a stream for the ActiveDevices property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn bitmap_location(&self) -> Result<Vec<u8>>

BitmapLocation property

pub fn cached_bitmap_location( &self, ) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>

BitmapLocation property Get the cached value of the BitmapLocation property, or None if the property is not cached.

pub fn receive_bitmap_location_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>

BitmapLocation property Create a stream for the BitmapLocation property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn child_configuration( &self, ) -> Result<Vec<(String, HashMap<String, OwnedValue>)>>

ChildConfiguration property

pub fn cached_child_configuration( &self, ) -> Result<Option<<Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>

ChildConfiguration property Get the cached value of the ChildConfiguration property, or None if the property is not cached.

pub fn receive_child_configuration_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>

ChildConfiguration property Create a stream for the ChildConfiguration property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn chunk_size(&self) -> Result<u64>

ChunkSize property

pub fn cached_chunk_size( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

ChunkSize property Get the cached value of the ChunkSize property, or None if the property is not cached.

pub fn receive_chunk_size_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>

ChunkSize property Create a stream for the ChunkSize property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn degraded(&self) -> Result<u32>

Degraded property

pub fn cached_degraded( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

Degraded property Get the cached value of the Degraded property, or None if the property is not cached.

pub fn receive_degraded_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>

Degraded property Create a stream for the Degraded property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn level(&self) -> Result<String>

Level property

pub fn cached_level( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

Level property Get the cached value of the Level property, or None if the property is not cached.

pub fn receive_level_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>

Level property Create a stream for the Level property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn name(&self) -> Result<String>

Name property

pub fn cached_name( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

Name property Get the cached value of the Name property, or None if the property is not cached.

pub fn receive_name_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>

Name property Create a stream for the Name property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn num_devices(&self) -> Result<u32>

NumDevices property

pub fn cached_num_devices( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>

NumDevices property Get the cached value of the NumDevices property, or None if the property is not cached.

pub fn receive_num_devices_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>

NumDevices property Create a stream for the NumDevices property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn running(&self) -> Result<bool>

Running property

pub fn cached_running( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>

Running property Get the cached value of the Running property, or None if the property is not cached.

pub fn receive_running_changed( &self, ) -> PropertyIterator<'p, <Result<bool> as ResultAdapter>::Ok>

Running property Create a stream for the Running property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn size(&self) -> Result<u64>

Size property

pub fn cached_size( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

Size property Get the cached value of the Size property, or None if the property is not cached.

pub fn receive_size_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>

Size property Create a stream for the Size property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn sync_action(&self) -> Result<String>

SyncAction property

pub fn cached_sync_action( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

SyncAction property Get the cached value of the SyncAction property, or None if the property is not cached.

pub fn receive_sync_action_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>

SyncAction property Create a stream for the SyncAction property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn sync_completed(&self) -> Result<f64>

SyncCompleted property

pub fn cached_sync_completed( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>

SyncCompleted property Get the cached value of the SyncCompleted property, or None if the property is not cached.

pub fn receive_sync_completed_changed( &self, ) -> PropertyIterator<'p, <Result<f64> as ResultAdapter>::Ok>

SyncCompleted property Create a stream for the SyncCompleted property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn sync_rate(&self) -> Result<u64>

SyncRate property

pub fn cached_sync_rate( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

SyncRate property Get the cached value of the SyncRate property, or None if the property is not cached.

pub fn receive_sync_rate_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>

SyncRate property Create a stream for the SyncRate property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn sync_remaining_time(&self) -> Result<u64>

SyncRemainingTime property

pub fn cached_sync_remaining_time( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>

SyncRemainingTime property Get the cached value of the SyncRemainingTime property, or None if the property is not cached.

pub fn receive_sync_remaining_time_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>

SyncRemainingTime property Create a stream for the SyncRemainingTime property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.

pub fn uuid(&self) -> Result<String>

UUID property

pub fn cached_uuid( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>

UUID property Get the cached value of the UUID property, or None if the property is not cached.

pub fn receive_uuid_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>

UUID property Create a stream for the UUID property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.