pub struct MDRaidProxyBlocking<'p>(/* private fields */);Implementations
Sourceimpl<'p> MDRaidProxyBlocking<'p>
impl<'p> MDRaidProxyBlocking<'p>
Sourcepub fn new(conn: &Connection) -> Result<MDRaidProxyBlocking<'p>>
pub fn new(conn: &Connection) -> Result<MDRaidProxyBlocking<'p>>
Creates a new proxy with the default service and path.
Sourcepub fn builder(conn: &Connection) -> Builder<'p, Self>
pub fn builder(conn: &Connection) -> Builder<'p, Self>
Returns a customizable builder for this proxy.
Sourcepub fn into_inner(self) -> Proxy<'p>
pub fn into_inner(self) -> Proxy<'p>
Consumes self, returning the underlying zbus::Proxy.
Sourcepub fn inner_mut(&mut self) -> &mut Proxy<'p>
pub fn inner_mut(&mut self) -> &mut Proxy<'p>
The mutable reference to the underlying zbus::Proxy.
Sourcepub fn add_device(
&self,
device: &ObjectPath<'_>,
options: HashMap<&str, Value<'_>>,
) -> Result<()>
pub fn add_device( &self, device: &ObjectPath<'_>, options: HashMap<&str, Value<'_>>, ) -> Result<()>
AddDevice method
Sourcepub fn remove_device(
&self,
device: &ObjectPath<'_>,
options: HashMap<&str, Value<'_>>,
) -> Result<()>
pub fn remove_device( &self, device: &ObjectPath<'_>, options: HashMap<&str, Value<'_>>, ) -> Result<()>
RemoveDevice method
Sourcepub fn request_sync_action(
&self,
sync_action: &str,
options: HashMap<&str, Value<'_>>,
) -> Result<()>
pub fn request_sync_action( &self, sync_action: &str, options: HashMap<&str, Value<'_>>, ) -> Result<()>
RequestSyncAction method
Sourcepub fn set_bitmap_location(
&self,
value: &[u8],
options: HashMap<&str, Value<'_>>,
) -> Result<()>
pub fn set_bitmap_location( &self, value: &[u8], options: HashMap<&str, Value<'_>>, ) -> Result<()>
SetBitmapLocation method
Sourcepub fn active_devices(
&self,
) -> Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>>
pub fn active_devices( &self, ) -> Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>>
ActiveDevices property
Sourcepub fn cached_active_devices(
&self,
) -> Result<Option<<Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>
pub fn cached_active_devices( &self, ) -> Result<Option<<Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>
ActiveDevices property
Get the cached value of the ActiveDevices property, or None if the property is not cached.
Sourcepub fn receive_active_devices_changed(
&self,
) -> PropertyIterator<'p, <Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>
pub fn receive_active_devices_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<(OwnedObjectPath, i32, Vec<String>, u64, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>
ActiveDevices property
Create a stream for the ActiveDevices property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn bitmap_location(&self) -> Result<Vec<u8>>
pub fn bitmap_location(&self) -> Result<Vec<u8>>
BitmapLocation property
Sourcepub fn cached_bitmap_location(
&self,
) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>
pub fn cached_bitmap_location( &self, ) -> Result<Option<<Result<Vec<u8>> as ResultAdapter>::Ok>, <Result<Vec<u8>> as ResultAdapter>::Err>
BitmapLocation property
Get the cached value of the BitmapLocation property, or None if the property is not cached.
Sourcepub fn receive_bitmap_location_changed(
&self,
) -> PropertyIterator<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>
pub fn receive_bitmap_location_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<u8>> as ResultAdapter>::Ok>
BitmapLocation property
Create a stream for the BitmapLocation property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn child_configuration(
&self,
) -> Result<Vec<(String, HashMap<String, OwnedValue>)>>
pub fn child_configuration( &self, ) -> Result<Vec<(String, HashMap<String, OwnedValue>)>>
ChildConfiguration property
Sourcepub fn cached_child_configuration(
&self,
) -> Result<Option<<Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>
pub fn cached_child_configuration( &self, ) -> Result<Option<<Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Err>
ChildConfiguration property
Get the cached value of the ChildConfiguration property, or None if the property is not cached.
Sourcepub fn receive_child_configuration_changed(
&self,
) -> PropertyIterator<'p, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>
pub fn receive_child_configuration_changed( &self, ) -> PropertyIterator<'p, <Result<Vec<(String, HashMap<String, OwnedValue>)>> as ResultAdapter>::Ok>
ChildConfiguration property
Create a stream for the ChildConfiguration property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn chunk_size(&self) -> Result<u64>
pub fn chunk_size(&self) -> Result<u64>
ChunkSize property
Sourcepub fn cached_chunk_size(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_chunk_size( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
ChunkSize property
Get the cached value of the ChunkSize property, or None if the property is not cached.
Sourcepub fn receive_chunk_size_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_chunk_size_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
ChunkSize property
Create a stream for the ChunkSize property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_degraded(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_degraded( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
Degraded property
Get the cached value of the Degraded property, or None if the property is not cached.
Sourcepub fn receive_degraded_changed(
&self,
) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
pub fn receive_degraded_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
Degraded property
Create a stream for the Degraded property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_level(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_level( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
Level property
Get the cached value of the Level property, or None if the property is not cached.
Sourcepub fn receive_level_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_level_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
Level property
Create a stream for the Level property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_name(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_name( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
Name property
Get the cached value of the Name property, or None if the property is not cached.
Sourcepub fn receive_name_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_name_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
Name property
Create a stream for the Name property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn num_devices(&self) -> Result<u32>
pub fn num_devices(&self) -> Result<u32>
NumDevices property
Sourcepub fn cached_num_devices(
&self,
) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
pub fn cached_num_devices( &self, ) -> Result<Option<<Result<u32> as ResultAdapter>::Ok>, <Result<u32> as ResultAdapter>::Err>
NumDevices property
Get the cached value of the NumDevices property, or None if the property is not cached.
Sourcepub fn receive_num_devices_changed(
&self,
) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
pub fn receive_num_devices_changed( &self, ) -> PropertyIterator<'p, <Result<u32> as ResultAdapter>::Ok>
NumDevices property
Create a stream for the NumDevices property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_running(
&self,
) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
pub fn cached_running( &self, ) -> Result<Option<<Result<bool> as ResultAdapter>::Ok>, <Result<bool> as ResultAdapter>::Err>
Running property
Get the cached value of the Running property, or None if the property is not cached.
Sourcepub fn receive_running_changed(
&self,
) -> PropertyIterator<'p, <Result<bool> as ResultAdapter>::Ok>
pub fn receive_running_changed( &self, ) -> PropertyIterator<'p, <Result<bool> as ResultAdapter>::Ok>
Running property
Create a stream for the Running property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_size(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_size( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
Size property
Get the cached value of the Size property, or None if the property is not cached.
Sourcepub fn receive_size_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_size_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
Size property
Create a stream for the Size property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn sync_action(&self) -> Result<String>
pub fn sync_action(&self) -> Result<String>
SyncAction property
Sourcepub fn cached_sync_action(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_sync_action( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
SyncAction property
Get the cached value of the SyncAction property, or None if the property is not cached.
Sourcepub fn receive_sync_action_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_sync_action_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
SyncAction property
Create a stream for the SyncAction property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn sync_completed(&self) -> Result<f64>
pub fn sync_completed(&self) -> Result<f64>
SyncCompleted property
Sourcepub fn cached_sync_completed(
&self,
) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>
pub fn cached_sync_completed( &self, ) -> Result<Option<<Result<f64> as ResultAdapter>::Ok>, <Result<f64> as ResultAdapter>::Err>
SyncCompleted property
Get the cached value of the SyncCompleted property, or None if the property is not cached.
Sourcepub fn receive_sync_completed_changed(
&self,
) -> PropertyIterator<'p, <Result<f64> as ResultAdapter>::Ok>
pub fn receive_sync_completed_changed( &self, ) -> PropertyIterator<'p, <Result<f64> as ResultAdapter>::Ok>
SyncCompleted property
Create a stream for the SyncCompleted property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_sync_rate(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_sync_rate( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
SyncRate property
Get the cached value of the SyncRate property, or None if the property is not cached.
Sourcepub fn receive_sync_rate_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_sync_rate_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
SyncRate property
Create a stream for the SyncRate property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn sync_remaining_time(&self) -> Result<u64>
pub fn sync_remaining_time(&self) -> Result<u64>
SyncRemainingTime property
Sourcepub fn cached_sync_remaining_time(
&self,
) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
pub fn cached_sync_remaining_time( &self, ) -> Result<Option<<Result<u64> as ResultAdapter>::Ok>, <Result<u64> as ResultAdapter>::Err>
SyncRemainingTime property
Get the cached value of the SyncRemainingTime property, or None if the property is not cached.
Sourcepub fn receive_sync_remaining_time_changed(
&self,
) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
pub fn receive_sync_remaining_time_changed( &self, ) -> PropertyIterator<'p, <Result<u64> as ResultAdapter>::Ok>
SyncRemainingTime property
Create a stream for the SyncRemainingTime property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.
Sourcepub fn cached_uuid(
&self,
) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
pub fn cached_uuid( &self, ) -> Result<Option<<Result<String> as ResultAdapter>::Ok>, <Result<String> as ResultAdapter>::Err>
UUID property
Get the cached value of the UUID property, or None if the property is not cached.
Sourcepub fn receive_uuid_changed(
&self,
) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
pub fn receive_uuid_changed( &self, ) -> PropertyIterator<'p, <Result<String> as ResultAdapter>::Ok>
UUID property
Create a stream for the UUID property changes. This is a convenient wrapper around zbus::blocking::Proxy::receive_property_changed.